// *#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#* Configuration.h *#*#*#*#*#*#*#*#*#* (C) 2023 DekTec
//
// Code example AvFifo_VideoTx - Configuration
// 
// Standard configuration:
// - Video frame resolution: 1920x1080 pixels
// - IP address for transmission: 224.10.10.5, port 5000
// - SMPTE 2110-20 video format: 10-bit YCbCr-4:2:2, 50Hz
// - Number of balls in the simulation: 200
// - Ball radius: 5-30 pixels, ball speed 0-2 pixels/frame
// - Ball speed
//  

// -.-.-.-.-.-.-.-.-.-.-.- Include necessary headers and libraries -.-.-.-.-.-.-.-.-.-.-.-

#include "DTAPI_AvFifo.h"           // DekTec's AvFifo API, part of DTAPI.
#include "Generator.h"              // SMPTE 2110 video frame generator.

using namespace std;                // Avoid std:: prefix for standard library calls.
using namespace AvFifo;             // Avoid AvFifo:: prefix, keeping code concise.

// -.-.-.-.-.-.-.-.-.-.-.-.-.- SMPTE 2110 video configuration -.-.-.-.-.-.-.-.-.-.-.-.-.-.

// Frame size: 1920x1080 pixels
constexpr int FrameWidth{1920}, FrameHeight{1080};

// IP transmit configuration parameters.
const IpPars AvFifo_VideoTx_IpPars
{
    .IpAddr{239, 10, 10, 10},
    .IpVersion{IpProtocolVersion::IPv4},
    .Port{5000},
    // For SMPTE 2110, transport protocol must be set to RTP.
    .RtpPayloadType{96},
    .TransportProtocol{IpTransportProtocol::Rtp}
};

// SMPTE 2110 video format.
const St2110::TxConfigVideo AvFifo_VideoTx_Config
{
    .Format{St2110::TxFrameFormat::Uyvy422_10b},
    .Packing{false, St2110::PackingMode::General, -1},
    .Resolution{FrameWidth, FrameHeight},
    .Timing{{50, 1}, St2110::Scheduling::Linear, St2110::VideoScanning::Progressive}
};

// .-.-.-.-.-.-.-.-.-.-.-.- Moving balls simulation configuration -.-.-.-.-.-.-.-.-.-.-.-.

// Number of simulated moving balls.
constexpr int NumMovingBalls{200};

// Minimum and maximum radius of the balls.
constexpr int MinBallRadius{5}, MaxBallRadius{30};

// Minimum and maximum initial velocity of the balls in #pixels moved per frame.
constexpr double MinBallSpeed{0}, MaxBallSpeed{2};

// The frame's background color.
constexpr Color BackgroundColor{80, 200, 0};
